Learn R Programming

scpm (version 2.0.0)

A6. Obtain approximation: Linear approximation to a spline.

Description

Approximation to a spatial semiparametric model based on a bivariate spline.

Usage

# S4 method for sssFit
scpApproximate(object, tol)

Arguments

object

an object of class sssFit from command scp.

tol

numeric. Numeric tolerance to use for some inversion of matrices. Default to .Machine$double.neg.eps*1.0e-10.

Value

This command return an object of class sssFit.

Details

scpApproximate compute an approximation to the spatial semiparametric model obtained from scp. This command update the fitted values and fitted spline in the input object of class sssFit. Then we can use the command plot for plotting the approximated semiparametric model.