Approximation to a spatial semiparametric model based on a bivariate spline.
# S4 method for sssFit
scpApproximate(object, tol)an object of class sssFit from command scp.
numeric. Numeric tolerance to use for some inversion of matrices. Default to .Machine$double.neg.eps*1.0e-10.
This command return an object of class sssFit.
scpApproximate compute an approximation to the spatial semiparametric model obtained from scp. This command update the fitted values and fitted spline in the input object of class sssFit. Then we can use the command plot for plotting the approximated semiparametric model.